@@ -40,11 +40,12 @@ from skimage.exposure import rescale_intensity
 from skimage.measure import label
 
 
-def normalize(image):
+def normalize(image, epsilon=1e-07):
     """Normalize image data by dividing by the maximum pixel value
 
     Args:
         image (numpy.array): numpy array of image data
+        epsilon (float): fuzz factor used in numeric expressions.
 
     Returns:
         numpy.array: normalized image data
@@ -52,18 +53,19 @@ def normalize(image):
     for batch in range(image.shape[0]):
         for channel in range(image.shape[-1]):
             img = image[batch, ..., channel]
-            normal_image = (img - img.mean()) / img.std()
+            normal_image = (img - img.mean()) / (img.std() + epsilon)
             image[batch, ..., channel] = normal_image
     return image
 
 
-def histogram_normalization(image, kernel_size=64):
+def histogram_normalization(image, kernel_size=None):
     """Pre-process images using Contrast Limited Adaptive
     Histogram Equalization (CLAHE).
 
     Args:
         image (numpy.array): numpy array of phase image data.
-        kernel_size (integer): Size of kernel for CLAHE.
+        kernel_size (integer): Size of kernel for CLAHE,
+            defaults to 1/8 of image size.
 
     Returns:
         numpy.array: Pre-processed image data with dtype float32.
@@ -75,8 +77,9 @@ def histogram_normalization(image, kernel_size=64):
     for batch in range(image.shape[0]):
         for channel in range(image.shape[-1]):
             X = image[batch, ..., channel]
-            X = rescale_intensity(X, out_range='float')
-            X = equalize_adapthist(X, kernel_size=(kernel_size, kernel_size))
+            # X = rescale_intensity(X, out_range='float')
+            X = rescale_intensity(X, out_range=(0.0, 1.0))
+            X = equalize_adapthist(X, kernel_size=kernel_size)
             image[batch, ..., channel] = X
     return image
 
@@ -97,23 +100,21 @@ def percentile_threshold(image, percentile=99.9):
         for chan in range(image.shape[-1]):
             current_img = np.copy(image[img, ..., chan])
             non_zero_vals = current_img[np.nonzero(current_img)]
-            img_max = np.percentile(non_zero_vals, percentile)
 
-            # threshold values down to max
-            threshold_mask = current_img > img_max
-            current_img[threshold_mask] = img_max
+            # only threshold if channel isn't blank
+            if len(non_zero_vals) > 0:
+                img_max = np.percentile(non_zero_vals, percentile)
 
-            # update image
-            processed_image[img, ..., chan] = current_img
+                # threshold values down to max
+                threshold_mask = current_img > img_max
+                current_img[threshold_mask] = img_max
+
+                # update image
+                processed_image[img, ..., chan] = current_img
 
     return processed_image
 
 
-def phase_preprocess(image, kernel_size=64):
-    """Maintained for backwards compatability"""
-    return histogram_normalization(image=image, kernel_size=kernel_size)
-
-
 def mibi(prediction, edge_threshold=.25, interior_threshold=.25):
     """Post-processing for MIBI data. Uniquely segments every cell by
     repeatedly eroding and dilating the cell interior prediction  until a
@@ -289,3 +290,7 @@ def correct_drift(X, y=None):
         return X, y
 
     return X
+
+
+# alias for backwards compatibility
+phase_preprocess = histogram_normalization
